@@ -4,6 +4,8 @@ import warnings
 import yaml
 from contextlib import suppress
 
+from convisoappsec.logger import LOGGER
+
 
 class GitAdapter(object):
     LIST_OPTION = '--list'
@@ -15,6 +17,9 @@ class GitAdapter(object):
     EMPTY_REPOSITORY_HASH = '4b825dc642cb6eb9a060e54bf8d69288fbee4904'
 
     def __init__(self, repository_dir='.', load_remote_repositories_heads=True, unshallow_repository=True):
+        LOGGER.debug('Unshallow: {}'.format(unshallow_repository))
+        LOGGER.debug('Load remote: {}'.format(load_remote_repositories_heads))
+
         import git
         self._git_client = git.cmd.Git(repository_dir)
         self._first_commit = None
