@@ -7,6 +7,7 @@ from convisoappsec.flowcli.deploy.create.context import pass_create_context
 from convisoappsec.flow import GitAdapter
 from convisoappsec.flow import api
 from convisoappsec.flowcli.common import project_code_option, on_http_error
+from convisoappsec.logger import LOGGER
 
 
 @click.command()
@@ -48,7 +49,8 @@ def values(
 ):
     try:
         flow = flow_context.create_flow_api_client()
-        git_adapter = GitAdapter(repository_dir=repository_dir)
+        git_adapter = GitAdapter(repository_dir)
+
         current_commit = current_commit or git_adapter.head_commit
 
         if not previous_commit:
@@ -94,13 +96,20 @@ def values(
             previous_commit, current_commit
         )
 
+        deploy_metrics_msg_fmt = 'Fetching deploy metrics between [{}] and [{}]'
+        LOGGER.debug(deploy_metrics_msg_fmt.format(previous_commit, current_commit))
+        LOGGER.debug('Deploy metrics: {}'.format(deploy_metrics))
+
+        project_metrics_data = project_metrics(repository_dir)
+        LOGGER.debug('Project metrics: {}'.format(project_metrics_data))
+
         deploy = flow.deploys.create(
             project_code,
             current_version={'commit': current_commit},
             previous_version={'commit': previous_commit},
             diff_content=diff_content,
             metrics=deploy_metrics,
-            project_metrics=project_metrics(repository_dir),
+            project_metrics=project_metrics_data,
             commit_authors=authors_data
         )
 
