@@ -4,7 +4,7 @@ import click
 def print_help(ctx, param, value):
     if not value or ctx.resilient_parsing:
         return
-    click.echo_via_pager(ctx.get_help())
+    click.echo(ctx.get_help())
     ctx.exit()
 
 
